// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KOPENINGHOURS_VERSION_H
#define KOPENINGHOURS_VERSION_H

#define KOPENINGHOURS_VERSION_STRING "26.03.90"
#define KOPENINGHOURS_VERSION_MAJOR 26
#define KOPENINGHOURS_VERSION_MINOR 3
#define KOPENINGHOURS_VERSION_PATCH 90
#define KOPENINGHOURS_VERSION ((26<<16)|(3<<8)|(90))

#endif
